import { clearMarkTask, getTask } from "@/api/markPage";
import { useMarkStore } from "@/store";
import { nextTick, watch } from "vue";
import useTaskRejection from "./useTaskRejection";
import useDraw from "./useDraw";
import useStatus from "./useStatus";

export default function useMarkTask() {
  const markStore = useMarkStore();
  const { showRejectedReason } = useTaskRejection();
  const { updateStatus } = useStatus();
  const { processSliceUrls } = useDraw();

  let preDrawing = false;

  async function updateMarkTask() {
    await clearMarkTask();
  }

  async function updateTask() {
    const res = await getTask(markStore.setting.questionModal);
    if (res.data) {
      const newTask = res.data;
      newTask.sheetUrls = newTask.sheetUrls || [];
      try {
        preDrawing = true;
        newTask.sliceUrls = await processSliceUrls(newTask);
      } finally {
        preDrawing = false;
      }

      markStore.tasks.push(newTask);
      if (!markStore.historyOpen) {
        if (markStore.currentTask?.studentId !== markStore.tasks[0].studentId)
          markStore.currentTask = markStore.tasks[0];
      }

      if (markStore.status.totalCount - markStore.status.markedCount === 0) {
        await updateStatus();
      }

      if (markStore.tasks.length > 1) {
        await new Promise((resolve) => setTimeout(resolve, 3000));
      }
    } else {
      markStore.message = res.message || "数据错误";
    }

    if (!res.data && markStore.message === "成功")
      markStore.message = "当前无评卷任务";
  }

  function nextTask() {
    if (!preDrawing) {
      if (markStore.tasks.length < (markStore.setting.prefetchCount ?? 3)) {
        if (!markStore.historyOpen)
          return updateTask().catch((e) => console.log("定时获取任务出错", e));
      }
    }
  }

  function removeBrokenTask() {
    markStore.currentTask = undefined;

    if (markStore.historyOpen) {
      // 避免无限加载
      markStore.message = "加载失败，请重新选择。";
    } else {
      markStore.tasks.shift();
    }
  }

  function watchCurrentTask() {
    watch(
      () => markStore.currentTask,
      () => {
        // 重置当前选择的quesiton和score
        markStore.currentQuestion = undefined;
        markStore.currentScore = undefined;
        void nextTick(() => {
          if (markStore.currentTask) {
            showRejectedReason(markStore.currentTask);
          }
        });
      }
    );
  }

  watchCurrentTask();

  return {
    updateMarkTask,
    updateTask,
    nextTask,
    removeBrokenTask,
  };
}
