import { useMarkStore } from "@/store";
import { getStatus } from "@/api/markPage";
import { useTimers } from "@/setups/useTimers";
import { ref, watch } from "vue";

export default function useStatus() {
  const markStore = useMarkStore();

  const { addTimeout } = useTimers();
  // 试评、正评的页面提示
  const statusSpinning = ref(true);
  // 是否还在加载statusValue
  const loadingStatusSpinning = ref(true);

  async function updateStatus() {
    const res = await getStatus(markStore.setting.questionModal);
    markStore.setInfo({ status: res.data });
  }

  function setupStatusWatch() {
    watch(
      () => markStore.setting.statusValue,
      () => {
        if (markStore.setting.statusValue) {
          loadingStatusSpinning.value = false;
          addTimeout(() => (statusSpinning.value = false), 3000);
        }
      }
    );
  }

  setupStatusWatch();

  return {
    statusSpinning,
    loadingStatusSpinning,
    updateStatus,
    setupStatusWatch,
  };
}
